@@ -293,7 +293,8 @@ if _use_c:
     _shuffle_oid = _cbson._shuffle_oid
 
 _RE_TYPE = type(_valid_array_name)
-def _element_to_bson(name, value):
+def _element_to_bson(key, value):
+    name = _make_c_string(key)
     if isinstance(value, float):
         return "\x01" + name + struct.pack("<d", value)
     if isinstance(value, Binary):
@@ -313,11 +314,11 @@ def _element_to_bson(name, value):
         cstring = _make_c_string(value)
         length = struct.pack("<i", len(cstring))
         return "\x02" + name + length + cstring
-    if isinstance(value, (dict, SON)):
-        return "\x03" + name + BSON.from_dict(value)
+    if isinstance(value, dict):
+        return "\x03" + name + _dict_to_bson(value)
     if isinstance(value, (list, tuple)):
         as_dict = SON(zip([str(i) for i in range(len(value))], value))
-        return "\x04" + name + BSON.from_dict(as_dict)
+        return "\x04" + name + _dict_to_bson(as_dict)
     if isinstance(value, ObjectId):
         return "\x07" + name + _shuffle_oid(str(value))
     if value is True:
@@ -351,8 +352,25 @@ def _element_to_bson(name, value):
         ns = _make_c_string(value.collection())
         return "\x0C" + name + struct.pack("<i", len(ns)) + ns + _shuffle_oid(str(value.id()))
     raise InvalidDocument("cannot convert value of type %s to bson" % type(value))
-# if _use_c:
-#     _element_to_bson = _cbson._element_to_bson
+if _use_c:
+    _py_element_to_bson = _element_to_bson
+    _c_element_to_bson = _cbson._element_to_bson
+    def _element_to_bson(name, value):
+        try:
+            return _c_element_to_bson(name, value)
+        except _cbson.error:
+            return _py_element_to_bson(name, value)
+
+def _dict_to_bson(dict):
+    try:
+        elements = "".join([_element_to_bson(key, value) for (key, value) in dict.iteritems()])
+    except AttributeError:
+        raise TypeError("argument to from_dict must be a mapping type")
+
+    length = len(elements) + 5
+    return struct.pack("<i", length) + elements + "\x00"
+if _use_c:
+    _dict_to_bson = _cbson._dict_to_bson
 
 def is_valid(bson):
     """Validate that the given string represents valid BSON data.
@@ -412,14 +430,7 @@ class BSON(str):
         :Parameters:
           - `dict`: mapping type representing a Mongo document
         """
-        try:
-            elements = "".join([_element_to_bson(_make_c_string(key), value) for (key, value) in dict.iteritems()])
-        except AttributeError:
-            raise TypeError("argument to from_dict must be a mapping type")
-
-        length = len(elements) + 5
-        bson = struct.pack("<i", length) + elements + "\x00"
-        return cls(bson)
+        return cls(_dict_to_bson(dict))
 
     def to_dict(self):
         """Get the dictionary representation of this data."""
